@@ -1,4 +1,4 @@
-/* $Header: /local/src/CVS/nickle/opcode.h,v 1.29 2005/12/10 22:11:45 bart Exp $ */
+/* $Header$ */
 
 /*
  * Copyright © 1988-2004 Keith Packard and Bart Massey.
@@ -83,6 +83,8 @@ typedef enum _OpCode {
     OpAssign,
     OpAssignOp,
     OpAssignFunc,
+    OpIsType,
+    OpHasMember,
     OpEnd,
     OpDrop
 } __attribute__ ((packed)) OpCode;
